@@ -1,7 +1,9 @@
 use nom::error::ParseError;
 use quick_error::quick_error;
 quick_error! {
+    /// An error returned by various [`Commit`][crate::borrowed::Commit] and [`Signature`][crate::borrowed::Signature] methods
     #[derive(Debug)]
+    #[allow(missing_docs)]
     pub enum Error {
         ParseIntegerError(msg: &'static str, number: crate::BString, err: btoi::ParseIntegerError) {
             display("{}: {:?}", msg, number)
