@@ -1,3 +1,5 @@
+//! Mutable objects with each field being separately allocated and mutable.
+//!
 //! Owned objects are Commits, Trees, Blobs and Tags that can be mutated and serialized.
 
 pub(crate) const NL: &[u8; 1] = b"\n";
@@ -6,8 +8,7 @@ pub(crate) const SPACE: &[u8; 1] = b" ";
 mod convert;
 mod ser;
 
-mod id;
-pub use id::{Error, Id};
+pub use git_hash::owned::Digest as Id;
 
 mod tag;
 pub use tag::Tag;
